Helpers
=============

.. currentmodule:: aiortc

These classes are not part of the WebRTC or ORTC API, but provide higher-level
helpers for tasks like manipulating media streams.

Media sources
-------------

   .. autoclass:: aiortc.contrib.media.MediaPlayer
      :members:

Media sinks
-----------

   .. autoclass:: aiortc.contrib.media.MediaRecorder
      :members:

   .. autoclass:: aiortc.contrib.media.MediaBlackhole
      :members:

Media transforms
----------------

   .. autoclass:: aiortc.contrib.media.MediaRelay
      :members:
